#
# LDoms
#
# Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
# The Universal Permissive License (UPL), Version 1.0
#
# Subject to the condition set forth below, permission is hereby
# granted to any person obtaining a copy of this software, associated
# documentation and/or data (collectively the "Software"), free of
# charge and under any and all copyright rights in the Software, and
# any and all patent rights owned or freely licensable by each licensor
# hereunder covering either (i) the unmodified Software as contributed
# to or provided by such licensor, or (ii) the Larger Works (as defined
# below), to deal in both
#
# (a) the Software, and
# (b) any piece of software and/or hardware listed in the lrgrwrks.txt
# file if one is included with the Software (each a "Larger Work" to
# which the Software is contributed by such licensors),
#
# without restriction, including without limitation the rights to copy,
# create derivative works of, display, perform, and distribute the
# Software and make, use, sell, offer for sale, import, export, have
# made, and have sold the Software and the Larger Work(s), and to
# sublicense the foregoing rights on either these or other terms.
#
# This license is subject to the following condition: The above
# copyright notice and either this complete permission notice or at a
# minimum a reference to the UPL must be included in all copies or
# substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

#
# In order to build the source delivered by the source RPM, the
# following three variables need to be set to appropriate values
# and then run the three comamnds below (the version and build
# values can be determined from the source RPM numbering).
#
# export PKG_SOURCE="$HOME/rpmbuild/SOURCES"
# export PKG_VERSION=1.0.0
# export PKG_BUILD=1600
#
# cd $PKG_SOURCE
# tar xf ldoms-$PKG_VERSION-$PKG_BUILD.tar
# ksh ldoms-$PKG_VERSION/tools/build.ksh -w $PKG_SOURCE/ldoms-$PKG_VERSION
#
# In the future, we should look at doing this in the 'build' section.
#

Summary: Logical Domains Configuration and Administration
Name: ldoms%{?_variant}
Version: %{_version}
Release: %{_build}%{?dist}
Group: System Environment/Daemons
Vendor: Oracle America
License: UPL

Source0: %{_sourcedir}/ldoms-%{version}-%{_build}.tar

#
# Disable auto dependencies
#
AutoReqProv: no

BuildRequires: devtoolset-3-gcc
BuildRequires: glibc-devel
BuildRequires: libnl-devel
BuildRequires: rpm-build
BuildRequires: ksh
Conflicts: ldoms%{!?_variant:-debug}
Requires: glibc

# Need a manual dependency for the ldmconsole script
Requires: socat

#
# We have a dependency on kernel-uek 4.1.8-15 (Linux for SPARC 1.0)
# Requires: kernel-uek >= 4.1.8-15
# or
# kernel-uek 2.6.39-500.1.40 (Exadata Beta 2)
# Requires: kernel-uek >= 2.6.39-500.1.40
# to ensure we have the required compatible interfaces for libds and libpri.
# We cannot do multiple conditionals so we pick the lowest version
# (at the risk that older UEK4 builds would also be accepted but
#  won't have all the support)
#
Requires: kernel-uek >= 2.6.39-500.1.40

Provides: ldoms

%description
Provides logical domains (LDoms) platform support for guest domains running under Oracle VM Server for SPARC.  A logical domain is a hypervisor-based virtual machine consisting of a discrete logical grouping of resources that has its own operating system and identity within a single computer system.  Each logical domain is only permitted to observe and interact with those server resources that are made available to it by the hypervisor.

%prep
%setup -n ldoms-%{version}

%build

%install
cp -rp %{_root}/* %{buildroot}

%clean

%post
case "$1" in
  1)
    # Initial install - add service
    /sbin/chkconfig --add ldmad
    ;;
  2)
    # Upgrade - delete and re-add the service
    /sbin/chkconfig --del ldmad
    /sbin/chkconfig --add ldmad
    ;;
esac

%preun
case "$1" in
  0)
    # Uninstall
    /sbin/service ldmad stop
    /sbin/chkconfig --del ldmad
    ;;
esac

%files
%defattr(-,root,root,-)
%doc
/etc/init.d/ldmad
%config(noreplace) /etc/udev/rules.d/99-vsw.rules
%dir /usr/lib/ldoms
/usr/lib/ldoms/ldmad
/usr/lib/ldoms/mdprop.py
/usr/lib/ldoms/mdprop.pyc
/usr/lib/ldoms/mdprop.pyo
/usr/lib/ldoms/pri
/usr/lib/ldoms/vswcfg.sh
/usr/lib64/libds.so
/usr/lib64/libds.so.1
/usr/lib64/libpri.so
/usr/lib64/libpri.so.1
%dir /usr/lib64/python2.6/site-packages/ldoms
/usr/lib64/python2.6/site-packages/ldoms/__init__.py
/usr/lib64/python2.6/site-packages/ldoms/__init__.pyc
/usr/lib64/python2.6/site-packages/ldoms/__init__.pyo
/usr/lib64/python2.6/site-packages/ldoms/MD.py
/usr/lib64/python2.6/site-packages/ldoms/MD.pyc
/usr/lib64/python2.6/site-packages/ldoms/MD.pyo
/usr/lib64/python2.6/site-packages/ldoms/MDDecoder.py
/usr/lib64/python2.6/site-packages/ldoms/MDDecoder.pyc
/usr/lib64/python2.6/site-packages/ldoms/MDDecoder.pyo
/usr/lib64/python2.6/site-packages/ldoms/MDNodeDecoder.py
/usr/lib64/python2.6/site-packages/ldoms/MDNodeDecoder.pyc
/usr/lib64/python2.6/site-packages/ldoms/MDNodeDecoder.pyo
/usr/lib64/python2.6/site-packages/ldoms/sysfs.py
/usr/lib64/python2.6/site-packages/ldoms/sysfs.pyc
/usr/lib64/python2.6/site-packages/ldoms/sysfs.pyo
/usr/sbin/ldmconsole
/usr/sbin/ldmiov
%dir /usr/share/doc/ldoms
/usr/share/doc/ldoms/LICENSE

%changelog
